@@ -20,7 +20,10 @@ class Env:
 
 
 def get_filepath(*f):
-    return os.path.join(Env.app_root, *f)
+    root = os.path.normpath(Env.app_root)
+    res = os.path.normpath(os.path.join(root, *f))
+    assert os.path.commonpath([root, res]) == root
+    return res
 
 
 def get_default_java():
@@ -31,6 +34,15 @@ def get_default_java():
     return "java"
 
 
+def get_default_config():
+    return {
+        "java.path": "java",
+        "java.memory.min": "512M",
+        "java.memory.max": "2G",
+        "java.jvmargs": "-XX:+UnlockExperimentalVMOptions -XX:+UseG1GC -XX:G1NewSizePercent=20 -XX:G1ReservePercent=20 -XX:MaxGCPauseMillis=50 -XX:G1HeapRegionSize=32M",
+    }
+
+
 def get_default_root():
     MAP = {
         "linux": lambda: expanduser("~/.local/share/picomc"),
