@@ -2,17 +2,13 @@ import json
 import operator
 import os
 import posixpath
-import re
 import shutil
-import sys
 import urllib.parse
 import urllib.request
-from collections import defaultdict
 from functools import reduce
 from platform import architecture
 from string import Template
 
-import click
 import requests
 
 from picomc.downloader import DownloadQueue
@@ -81,7 +77,7 @@ class CachedVspecAttr(object):
                     )
                 except TypeError as e:
                     raise AttributeError() from e
-        except AttributeError as e:
+        except AttributeError:
             if self.default is not None:
                 r = self.default(vspec.vobj)
         finally:
@@ -441,67 +437,3 @@ class VersionManager:
 
     def get_version(self, version_name):
         return Version(self.resolve_version_name(version_name))
-
-
-g_vobj = None
-
-
-@click.group()
-@click.argument("version_name")
-def version_cli(version_name):
-    """Operate on local Minecraft versions."""
-    global g_vobj
-    g_vobj = Env.vm.get_version(version_name)
-
-
-@click.command()
-@click.option("--release", is_flag=True, default=False)
-@click.option("--snapshot", is_flag=True, default=False)
-@click.option("--alpha", is_flag=True, default=False)
-@click.option("--beta", is_flag=True, default=False)
-@click.option("--local", is_flag=True, default=False)
-@click.option("--all", is_flag=True, default=False)
-def list_versions(release, snapshot, alpha, beta, local, all):
-    """List available Minecraft versions."""
-    if all:
-        release = snapshot = alpha = beta = local = True
-    elif not (release or snapshot or alpha or beta):
-        logger.info(
-            "Showing only locally installed versions. "
-            "Use `version list --help` to get more info."
-        )
-        local = True
-    T = VersionType.create(release, snapshot, alpha, beta)
-    print("\n".join(Env.vm.version_list(vtype=T, local=local)))
-
-
-@version_cli.command()
-def prepare():
-    g_vobj.prepare()
-
-
-@version_cli.command()
-@click.argument("which", default="client")
-@click.option("--output", default=None)
-def jar(which, output):
-    """Download the file and save."""
-    dlspec = g_vobj.vspec.downloads.get(which, None)
-    if not dlspec:
-        die("No such dlspec exists for version {}".format(g_vobj.version_name))
-    url = dlspec["url"]
-    sha1 = dlspec["sha1"]
-    ext = posixpath.basename(urllib.parse.urlsplit(url).path).split(".")[-1]
-    if output is None:
-        output = "{}_{}.{}".format(g_vobj.version_name, which, ext)
-    if os.path.exists(output):
-        die("Refusing to overwrite {}".format(output))
-    logger.info("Hash should be {}".format(sha1))
-    logger.info("Downloading the {} file and saving to {}".format(which, output))
-    urllib.request.urlretrieve(dlspec["url"], output)
-    if file_sha1(output) != sha1:
-        logger.warn("Hash of downloaded file does not match")
-
-
-def register_version_cli(root_cli):
-    root_cli.add_command(version_cli, "version")
-    root_cli.add_command(list_versions)
